@@ -44,6 +44,7 @@ def build_upload_params(**options):
               "headers": build_custom_headers(options.get("headers")),
               "eager": build_eager(options.get("eager")),
               "use_filename": options.get("use_filename"),
+              "discard_original_filename": options.get("discard_original_filename"),
               "invalidate": options.get("invalidate"),
               "notification_url": options.get("notification_url"),
               "eager_notification_url": options.get("eager_notification_url"),
@@ -152,13 +153,7 @@ def text(text, **options):
 
 def call_api(action, params, **options):
     return_error = options.get("return_error")
-    api_key = options.get("api_key", cloudinary.config().api_key)
-    if not api_key: raise Exception("Must supply api_key")
-    api_secret = options.get("api_secret", cloudinary.config().api_secret)
-    if not api_secret: raise Exception("Must supply api_secret")
-
-    params["signature"] = utils.api_sign_request(params, api_secret)
-    params["api_key"] = api_key
+    params = utils.sign_request(params, options)
 
     param_list = []
     for k, v in params.items():
@@ -182,7 +177,7 @@ def call_api(action, params, **options):
         file = options["file"]
         if not isinstance(file, basestring):
             datagen, headers = multipart_encode({'file': file})
-        elif not re.match(r'^https?:', file):
+        elif not re.match(r'^https?:|^s3:|^data:image\/\w*;base64,([a-zA-Z0-9\/+\n=]+)$', file):
             datagen, headers = multipart_encode({'file': open(file, "rb")})
         else:
             param_list.append(("file", file))
